/*
 * VectorRangeValidator.hpp
 *
 *  Created on: Apr 13, 2012
 *      Author: ankele
 */

#ifndef VECTORRANGEVALIDATOR_HPP_
#define VECTORRANGEVALIDATOR_HPP_


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Validator.hpp"
#include "CodePatterns/Range.hpp"

/** A validator with an interval of valid values.
 *
 */
template <class T>
class VectorRangeValidator : public Validator<T>
{
public:
  VectorRangeValidator(const range<T> &_ValidRange) : ValidRange(_ValidRange) {};
  virtual ~VectorRangeValidator() {};

  bool isValid(const T & _value) const
  {
    return ValidRange.first[0] <= _value[0] && _value[0] < ValidRange.last[0] &&
           ValidRange.first[1] <= _value[1] && _value[1] < ValidRange.last[1] &&
           ValidRange.first[2] <= _value[2] && _value[2] < ValidRange.last[2];
  }

  Validator<T>* clone() const { return new RangeValidator<T>(ValidRange); };

  // comparator
  bool operator==(const Validator<T> &_instance) const
  {
    const VectorRangeValidator<T> *inst = dynamic_cast<const VectorRangeValidator<T> *>(&_instance);
    if (inst)
      return ValidRange == inst->ValidRange;
    return false;
  };

private:
  //!> valid range of values
  range<T> ValidRange;
};



#endif /* VECTORRANGEVALIDATOR_HPP_ */
